@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Hayo Baan's Dist::Zilla configuration
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 #pod =for test_synopsis
 #pod my @HAYOBAAN;
@@ -517,13 +517,16 @@ has meta_no_index_dirs => (
     default => sub { [ qw(corpus) ] },
 );
 
+sub _is_disabled {
+    my $self = shift;
+    my $plugin = shift;
+    return grep { $_ eq $plugin } @{$self->disable_test}
+}
+
 # Helper function to add a test, checks for disabled tests
 sub _add_test {
     my $self = shift;
-    return map {
-        my $plugin = ref $_ ? $_->[0] : $_;
-        grep { /^$plugin$/ } @{$self->disable_test} ? () : $_;
-    } @_;
+    return grep { ! $self->_is_disabled(ref $_ ? $_->[0] : $_) } @_;
 }
 
 #pod =for Pod::Coverage configure
@@ -774,7 +777,7 @@ Dist::Zilla::PluginBundle::Author::HAYOBAAN - Hayo Baan's Dist::Zilla configurat
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
