@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: HAYOBAAN's Pod::Weaver configuration
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 #pod =head1 DESCRIPTION
 #pod
@@ -19,11 +19,14 @@ our $VERSION = '0.004'; # VERSION
 #pod * Region collectors for:
 #pod
 #pod =for :list
-#pod * requires
-#pod * construct
-#pod * attr
-#pod * method
-#pod * func
+#pod * requires (Requirements)
+#pod * var (Variables)
+#pod * func (Functions)
+#pod * c_attr (Class Attributes)
+#pod * attr (Attributes)
+#pod * construct (Constructors)
+#pod * c_method (Class Methods)
+#pod * method (Methods)
 #pod
 #pod * Replacing the original pod statements with comments, allowing line
 #pod   numbers to stay the same between development and build versions.
@@ -52,6 +55,12 @@ our $VERSION = '0.004'; # VERSION
 #pod   [Collect / REQUIREMENTS]
 #pod   command = requires
 #pod
+#pod   [Collect / VARIABLES]
+#pod   command = var
+#pod
+#pod   [Collect / FUNCTIONS]
+#pod   command = func
+#pod
 #pod   [Collect / CLASS ATTRIBUTES]
 #pod   command = c_attr
 #pod
@@ -67,12 +76,6 @@ our $VERSION = '0.004'; # VERSION
 #pod   [Collect / METHODS]
 #pod   command = method
 #pod
-#pod   [Collect / VARIABLES]
-#pod   command = var
-#pod
-#pod   [Collect / FUNCTIONS]
-#pod   command = func
-#pod
 #pod   [Leftovers]
 #pod
 #pod   [Region /postlude]
@@ -144,13 +147,13 @@ sub mvp_bundle_config {
 
     for my $plugin (
         [ 'Requirements',     _exp('Collect'), { command => 'requires' } ],
+        [ 'Variables',        _exp('Collect'), { command => 'var' } ],
+        [ 'Functions',        _exp('Collect'), { command => 'func' } ],
         [ 'Class Attributes', _exp('Collect'), { command => 'c_attr' } ],
         [ 'Attributes',       _exp('Collect'), { command => 'attr' } ],
         [ 'Constructors',     _exp('Collect'), { command => 'construct' } ],
         [ 'Class Methods',    _exp('Collect'), { command => 'c_method' } ],
         [ 'Methods',          _exp('Collect'), { command => 'method' } ],
-        [ 'Variables',        _exp('Collect'), { command => 'var' } ],
-        [ 'Functions',        _exp('Collect'), { command => 'func' } ],
     ) {
         $plugin->[2]{header} = uc $plugin->[0];
         push @plugins, $plugin;
@@ -190,7 +193,7 @@ Pod::Weaver::PluginBundle::Author::HAYOBAAN - HAYOBAAN's Pod::Weaver configurati
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -213,23 +216,35 @@ Region collectors for:
 
 =item *
 
-requires
+requires (Requirements)
 
 =item *
 
-construct
+var (Variables)
 
 =item *
 
-attr
+func (Functions)
 
 =item *
 
-method
+c_attr (Class Attributes)
 
 =item *
 
-func
+attr (Attributes)
+
+=item *
+
+construct (Constructors)
+
+=item *
+
+c_method (Class Methods)
+
+=item *
+
+method (Methods)
 
 =back
 
@@ -261,6 +276,12 @@ It is roughly equivalent to the following weaver.ini:
   [Collect / REQUIREMENTS]
   command = requires
 
+  [Collect / VARIABLES]
+  command = var
+
+  [Collect / FUNCTIONS]
+  command = func
+
   [Collect / CLASS ATTRIBUTES]
   command = c_attr
 
@@ -276,12 +297,6 @@ It is roughly equivalent to the following weaver.ini:
   [Collect / METHODS]
   command = method
 
-  [Collect / VARIABLES]
-  command = var
-
-  [Collect / FUNCTIONS]
-  command = func
-
   [Leftovers]
 
   [Region /postlude]
